# SmartCity-simulator
Smart City Simulator designed for hackathons !


Quelques idéees :
Matrice d'interraction pour people-lights & people-heaters & people-neighborhood ...
Comme ça on peut faire les cochons et en 3 multiplications on a défini qui appartenait où et on peut aller vite